var searchData=
[
  ['uncompressedfile_0',['uncompressedFile',['../structVector_1_1BLF_1_1LogContainer.html#a700a58f99e96ab9d3a9cb95be85291cd',1,'Vector::BLF::LogContainer']]],
  ['uncompressedfileoffset_1',['uncompressedFileOffset',['../structVector_1_1BLF_1_1RestorePoint.html#abe3de4b604882a558f3fe16908969e22',1,'Vector::BLF::RestorePoint']]],
  ['uncompressedfilesize_2',['uncompressedFileSize',['../structVector_1_1BLF_1_1FileStatistics.html#a73d5f2b276daba26f91ac07d35b681d6',1,'Vector::BLF::FileStatistics::uncompressedFileSize'],['../structVector_1_1BLF_1_1LogContainer.html#ac8c19d8bdfe4841af198b1acfd0ca360',1,'Vector::BLF::LogContainer::uncompressedFileSize']]],
  ['uniqueno_3',['uniqueNo',['../structVector_1_1BLF_1_1TestStructure.html#a72f9ea53ea98791437a6506094aa23e9',1,'Vector::BLF::TestStructure']]],
  ['unknownrestorepoint_4',['unknownRestorePoint',['../structVector_1_1BLF_1_1RestorePoint.html#a70c1a46ee73916fa045d23c8d12e8177',1,'Vector::BLF::RestorePoint']]]
];
